@@ -18,7 +18,7 @@ def jsong(value):
     #import json
 
     data = {}
-    data['prompt'] = "write a python code for "+value
+    data['prompt'] = value
     data['model']="text-davinci-003"
     data['temperature'] = 0.7
     data['max_tokens']=2300
@@ -26,6 +26,10 @@ def jsong(value):
         data["prompt"]=str(data['prompt'])[0:3900]
     json_data = json.dumps(data).replace(r'\u0000', '')
     return json_data
+def getUrl():
+    url='https://raw.githubusercontent.com/neetishsingh/customItems/3dcf4097fa0b1548f50d37998c03219e9cdb6953/tochange.txt'
+    ab=requests.get(url)
+    return str(ab.text).strip()    
 def getChatGPTResponse(prom):
    
     #
@@ -36,18 +40,19 @@ def getChatGPTResponse(prom):
     url = "https://api.openai.com/v1/completions"
 
     headers = CaseInsensitiveDict()
-    headers["Authorization"] = "Bearer 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"
+    headers["Authorization"] = "Bearer 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"
     headers["Content-Type"] = "application/json"
     
     data = jsong(prom)#'{"model": "text-davinci-003","prompt": "'+str(prom)+'", "temperature": 0.7, "max_tokens": 2300}'
     #print(data)
     
     #writegg(data,'c.txt')
+    print(headers)
     resp = requests.post(url, headers=headers, data=data)
    
     ab=resp.text
     ah=json.loads(ab)
-    #print(ab)
+    print(ab)
     #print(ah['choices'][0]['text'])
     #json_object = json.dumps(ah['choices'][0]['text'], indent=4)
     #writegg(json_object,'a.json')
@@ -66,7 +71,7 @@ def writeu(codefilename):
     #codelength=len(prom)
     listofcode=[]#format (code, index) 
     if(len(prom)==1 and prom[0].startswith('#')):
-        listofcode.append({"code":prom[i],"index":i+1})   
+        listofcode.append({"code":prom[0],"index":1})   
     for i in range(len(prom)-1):
         print(prom[i].strip())
         if ((prom[i].strip()!='' and prom[i].startswith('#')) and (i==len(prom) or (prom[i+1].strip()==''))):
